@@ -50,9 +50,7 @@ def load_model(context: Context, scan_model=True, check_for_config_with_same_nam
     sd = sd["state_dict"] if "state_dict" in sd else sd
 
     if is_lora(sd):
-        raise Exception(
-            "The model file doesn't contain a model's checkpoint. Instead, it seems to be a LORA file."
-        )
+        raise Exception("The model file doesn't contain a model's checkpoint. Instead, it seems to be a LORA file.")
 
     # try to guess the config, if no config file was given
     # check if a key specific to SD 2.0 is missing
@@ -239,8 +237,9 @@ def resolve_model_config_file_path(model_info, model_path):
 
     return config_file_path
 
+
 def is_lora(sd):
     heads = list(set([s[:5] for s in sd.keys()]))
-    for h in heads:
-       log.info(f"Header '{h}'")
-    return 'lora_' in heads and 'first' not in heads and 'cond_' not in heads
+    # for h in heads:
+    #    log.info(f"Header '{h}'")
+    return "lora_" in heads and "first" not in heads and "cond_" not in heads
